// ****************************************************************** 
//       * Functions triggered by events in client user interface
// ******************************************************************

// ************************************************************************************
// Name   : client_SetTxAupcMode()
// Purpose: Called when user selects a transmit AUPC mode from the TxAupcMode combo box.
//          This function extracts the edit box value and sends the value to the server.
// Inputs : NONE
// Outputs: NONE
function client_SetTxAupcMode()
{
   var anElement = Get_Iframe_Element( 'TxAupcModeSelect' ) ;
   if ( anElement )
   {
      if (IsChangeConfirmed("Tx Aupc Mode"))
      {
         serverXmitAupcIntf.SetTxAupcMode(parseInt(anElement.value, 10));
         Focus_Iframe();
      }
   }
};

// ************************************************************************************
// Name   : client_SetTxAupcEbno()
// Purpose: Called when user selects a transmit data rate from the TxAupcEbno edit box.
//          This function extracts the edit box value and sends the value to the server.
// Inputs : anEvent
// Outputs: NONE
function client_SetTxAupcEbno(anEvent)
{
   anEvent = (anEvent) ? anEvent : event;
   var charCode = (anEvent.charCode) ? anEvent.charCode : 
                  ((anEvent.which) ? anEvent.which : anEvent.keyCode);
   if (charCode == 13 || charCode == 3)
   {
      var anElement = Get_Iframe_Element( 'TxAupcEbnoInput' ) ;
      if ( anElement )
      {
         if (IsNumber(anElement))
         {
            if (IsChangeConfirmed("Tx Aupc Eb/No"))
            {
               var anEbno = parseFloat(anElement.value);
               anEbno += 0.000001;
               serverXmitAupcIntf.SetTxAupcEbno(anEbno);
               Focus_Iframe();
            }
         }
      }
   }
};

// ************************************************************************************
// Name   : client_SetTxAupcMinPower()
// Purpose: Called when user selects a transmit data rate from the TxAupcMinPower edit box.
//          This function extracts the edit box value and sends the value to the server.
// Inputs : anEvent
// Outputs: NONE
function client_SetTxAupcMinPower(anEvent)
{
   anEvent = (anEvent) ? anEvent : event;
   var charCode = (anEvent.charCode) ? anEvent.charCode : 
                  ((anEvent.which) ? anEvent.which : anEvent.keyCode);
   if (charCode == 13 || charCode == 3)
   {
      var anElement = Get_Iframe_Element( 'TxAupcMinPowerInput' ) ;
      if ( anElement )
      {
         if (IsNumber(anElement))
         {
            if (IsChangeConfirmed("Tx Aupc Minimum Power"))
            {
               var aPower = parseFloat(anElement.value);
               anElement.value = FormatNumber(aPower, 1);
               aPower += 0.000001;
               serverXmitAupcIntf.SetTxAupcMinPower(aPower);
               Focus_Iframe();
            }
         }
      }
   }
};

// ************************************************************************************
// Name   : client_SetTxAupcMaxPower()
// Purpose: Called when user selects a transmit Aupc max power from the TxAupcMaxPower edit box.
//          This function extracts the edit box value and sends the value to the server.
// Inputs : anEvent
// Outputs: NONE
function client_SetTxAupcMaxPower(anEvent)
{
   anEvent = (anEvent) ? anEvent : event;
   var charCode = (anEvent.charCode) ? anEvent.charCode : 
                  ((anEvent.which) ? anEvent.which : anEvent.keyCode);
   if (charCode == 13 || charCode == 3)
   {
      var anElement = Get_Iframe_Element( 'TxAupcMaxPowerInput' ) ;
      if ( anElement )
      {
         if (IsNumber(anElement))
         {
            if (IsChangeConfirmed("Tx Aupc Maximum Power"))
            {
               var aPower = parseFloat(anElement.value);
               anElement.value = FormatNumber(aPower, 1);
               aPower += 0.000001;
               serverXmitAupcIntf.SetTxAupcMaxPower(aPower);
               Focus_Iframe();
            }
         }
      }
   }
};

// ************************************************************************************
// Name   : client_SetTxAupcDefPower()
// Purpose: Called when user selects a transmit Aupc default power from the TxAupcDefPower edit box.
//          This function extracts the edit box value and sends the value to the server.
// Inputs : anEvent
// Outputs: NONE
function client_SetTxAupcDefPower(anEvent)
{
   anEvent = (anEvent) ? anEvent : event;
   var charCode = (anEvent.charCode) ? anEvent.charCode : 
                  ((anEvent.which) ? anEvent.which : anEvent.keyCode);
   if (charCode == 13 || charCode == 3)
   {
      var anElement = Get_Iframe_Element( 'TxAupcDefPowerInput' ) ;
      if ( anElement )
      {
         if (IsNumber(anElement))
         {
            if (IsChangeConfirmed("Tx Aupc Default Power"))
            {
               var aPower = parseFloat(anElement.value);
               anElement.value = FormatNumber(aPower, 1);
               aPower += 0.000001;
               serverXmitAupcIntf.SetTxAupcDefPower(aPower);
               Focus_Iframe();
            }
         }
      }
   }
};

// ************************************************************************************
// Name   : client_SetTxAupcStatusUpdate()
// Purpose: Called when the current iFrame loads
// Inputs : NONE
// Outputs: NONE
function client_SetTxAupcStatusUpdate()
{
   serverXmitAupcIntf.SetTxAupcSelectContentUpdate();
   serverXmitAupcIntf.SetTxAupcStatusUpdate();
};


// ****************************************************************** 
// * Functions called asynchronously from the server.
// ******************************************************************

function asyncUpdateXmitAupcModeStatus(anAupcMode)
{
   var anElement = Get_Iframe_Element( 'TxAupcModeSelect' ) ;
   if ( anElement )
      anElement.value = anAupcMode;
}

function asyncUpdateXmitAupcEbnoStatus(anAupcEbno)
{
   var anElement = Get_Iframe_Element( 'TxAupcEbnoInput' ) ;
   if ( anElement )
      anElement.value = anAupcEbno;
}

var aupcRemoteEbno = 0.0;
var aupcRemoteEbnoStatus = 0;
function formatAupcRemoteEbnoStatus(anEbno, anEbnoStatus)
{
   if (anEbnoStatus == 1)
      str = FormatNumber(anEbno, 1);
   else if (anEbnoStatus == 2)
      str = "< " + FormatNumber(anEbno, 1);
   else if (anEbnoStatus == 4)
      str = "> " + FormatNumber(anEbno, 1);
   else
      str = "NO SYNC";
	return(str);
}

function asyncUpdateXmitAupcRemoteEbnoStatus(anAupcEbno)
{
   // Set receive EbNo
   var anElement = Get_Iframe_Element('TxAupcRemoteEbnoInput');
   if ( anElement )
   {	      
      aupcRemoteEbno = anAupcEbno;        
      anElement.value = formatAupcRemoteEbnoStatus(aupcRemoteEbno, aupcRemoteEbnoStatus)
   }
}

function asyncUpdateXmitAupcRemoteEbnoValidityStatus(anAupcEbnoStatus)
{
   // Set receive EbNo
   var anElement = Get_Iframe_Element('TxAupcRemoteEbnoInput');
   if ( anElement )	                 
   {	      
      aupcRemoteEbnoStatus = anAupcEbnoStatus;        
      anElement.value = formatAupcRemoteEbnoStatus(aupcRemoteEbno, aupcRemoteEbnoStatus)
   }
}

function asyncUpdateXmitAupcMinPowerStatus(anAupcMinPower)
{
   var anElement = Get_Iframe_Element( 'TxAupcMinPowerInput' ) ;
   if ( anElement )
      anElement.value = FormatNumber(anAupcMinPower, 1);
}

function asyncUpdateXmitAupcMaxPowerStatus(anAupcMaxPower)
{
   var anElement = Get_Iframe_Element( 'TxAupcMaxPowerInput' ) ;
   if ( anElement )
      anElement.value = FormatNumber(anAupcMaxPower, 1);
}

function asyncUpdateXmitAupcDefPowerStatus(anAupcDefPower)
{
   var anElement = Get_Iframe_Element( 'TxAupcDefPowerInput' ) ;
   if ( anElement )
      anElement.value = FormatNumber(anAupcDefPower, 1);
}

// ****************************************************************** 
// * Functions to update the select content.
// ******************************************************************

function asyncUpdateXmitAupcModeSelectContent(aSelectContent)
{
   Update_Iframe_Element_Select_Content( 'TxAupcModeSelect', aSelectContent );
}

